# babelone
> pronounced /ˌbæbɪˈloʊn/

## Installation
```bash
pip install babelone
```

## Usage
```bash
babelone --help

babelone <path>/[requirements.txt|setup.py|pyproject.toml] <path>/[requirements.txt|setup.py|pyproject.toml]
```
